@@ -28,6 +28,26 @@ create.qqplot.fit <- function(
 	style = 'BoutrosLab', preload.default = 'custom', use.legacy.settings = FALSE, inside.legend.auto = FALSE
 	) {
 
+	### store data on mount
+        tryCatch({
+                        dir.name <- '/.mounts/labs/boutroslab/private/BPGRecords/Objects';
+			if( !dir.exists(dir.name) ) {
+                                dir.create(dir.name);
+                                }                        
+			funcname <- 'create.qqplot.fit';
+                        if(is.null(data)) {
+                                print.to.file(dir.name, funcname, x, filename);
+                                }
+                        else {
+                                print.to.file(dir.name, funcname, data, filename);
+                                }
+
+			},
+                warning = function(w) {
+                        },
+                error = function(e) {
+                	});
+
 	### needed to copy in case using variable to define rectangles dimensions
         rectangle.info <- list(
         	xright = xright.rectangle,
@@ -177,7 +197,7 @@ create.qqplot.fit <- function(
 				}
 
 			if (reference.line.method == 'robust' & !confidence.bands) {
-				tmp.data <- create.qqplot.fit.confidence.interval(
+				tmp.data <- BoutrosLab.plotting.general::create.qqplot.fit.confidence.interval(
 					x = x,
 					distribution = distribution,
 					conf = conf,
@@ -197,7 +217,7 @@ create.qqplot.fit <- function(
 				if (is.null(groups)) {
 
 					# store the value to create the confidence bands
-					tmp.ci <- create.qqplot.fit.confidence.interval(
+					tmp.ci <- BoutrosLab.plotting.general::create.qqplot.fit.confidence.interval(
 						x = x,
 						distribution = distribution,
 						conf = conf,
@@ -290,7 +310,7 @@ create.qqplot.fit <- function(
 					for (k in 1:number.groups) {
 
 						# store the value to create the confidence bands for each group
-						tmp.ci <- create.qqplot.fit.confidence.interval(
+						tmp.ci <- BoutrosLab.plotting.general::create.qqplot.fit.confidence.interval(
 							x = grouped.data[[groups.names[k]]],
 							distribution = distribution,
 							conf = conf,
